@@ -1,6 +1,6 @@
 #ifndef GINGERBLUE_CONFIG_H
 #define GINGERBLUE_CONFIG_H 1
 
-GtkWidget *main_config (gchar *location_data);
+GtkWidget *main_config (GtkWidget *widget, gpointer *location_data) {
 
 #endif /* GINGERBLUE_CONFIG_H */
