@@ -3,7 +3,7 @@
    Copyright (C) 2018-2021 Aamot Software
    Author(s): Ole Aamot <ole@gnome.org>
    License: GNU GPL version 3
-   Version: 0.7.0 (2021-07-14)
+   Version: 1.1.0 (2021-07-27)
    Website: http://www.gingerblue.org/
 
  */
@@ -13,13 +13,22 @@
 #include <glib/gi18n.h>
 #include <gst/gst.h>
 #include <gst/player/player.h>
+#include <gst/tag/tag.h>
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
+#include <champlain/champlain.h>
+#include <champlain-gtk/champlain-gtk.h>
+#include <string.h>
 #include "gingerblue.h"
 #include "gingerblue-chord.h"
 #include "gingerblue-main.h"
 #include "gingerblue-record.h"
+#include "gingerblue-studio-config.h"
+#include "gingerblue-studio-location.h"
+#include "gingerblue-studio-stream.h"
+
+GingerblueData *Gingerblue;
 
 static void gb_assistant_entry_changed(GtkEditable *, GtkAssistant *,
 				       GstElement *);
@@ -45,10 +54,18 @@ GtkWidget *line_entry, *line_label;
 GtkWidget *computer_entry, *computer_label;
 GtkWidget *recording_entry, *recording_label;
 GtkWidget *studio_entry, *studio_label;
+GtkWidget *stream_entry, *stream_label;
+GtkWidget *album_entry, *album_label;
 GtkWidget *summary_entry, *summary_label;
 
 GMainLoop *main_loops;
 
+GstPlayer *player;
+
+GstTagList *tag_list;
+
+GError *error = NULL;
+
 static void gb_assistant_entry_changed(GtkEditable * editable,
 				       GtkAssistant * assistant,
 				       GstElement * pipeline)
@@ -88,15 +105,31 @@ static void gb_assistant_button_clicked(GtkButton * button,
 				 "/", gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
 				 gtk_entry_get_text(GTK_ENTRY(song_entry)),
 				 ".ogg", NULL), NULL);
-
 	gst_bin_add_many(GST_BIN(recorder), src, conv, enc, muxer, sink, NULL);
 	gst_element_link_many(src, conv, enc, muxer, sink, NULL);
-
 	gst_element_set_state(recorder, GST_STATE_PLAYING);
-
+	tag_list = gst_tag_list_new (GST_TAG_ARTIST, gtk_entry_get_text(GTK_ENTRY(musician_entry)), NULL);
+	gst_stream_set_tags (GST_STREAM (recorder), tag_list);
+	tag_list = gst_tag_list_new (GST_TAG_ALBUM, gtk_entry_get_text(GTK_ENTRY(song_entry)), NULL);
+	gst_stream_set_tags (GST_STREAM (recorder), tag_list);
+	tag_list = gst_tag_list_new (GST_TAG_TITLE, gtk_entry_get_text(GTK_ENTRY(song_entry)), NULL);
+	gst_stream_set_tags (GST_STREAM (recorder), tag_list);
+	tag_list = gst_tag_list_new (GST_TAG_COPYRIGHT, gtk_entry_get_text(GTK_ENTRY(label_entry)), NULL);
+	gst_stream_set_tags (GST_STREAM (recorder), tag_list);
+	tag_list = gst_tag_list_new (GST_TAG_PUBLISHER, gtk_entry_get_text(GTK_ENTRY(label_entry)), NULL);
+	gst_stream_set_tags (GST_STREAM (recorder), tag_list);
+	tag_list = gst_tag_list_new (GST_TAG_DATE_TIME, datestamp, NULL);
+	gst_stream_set_tags (GST_STREAM (recorder), tag_list);
+	gst_vorbis_tag_add (tag_list, GST_TAG_ARTIST, gtk_entry_get_text(GTK_ENTRY(musician_entry)));
+	gst_vorbis_tag_add (tag_list, GST_TAG_ALBUM, gtk_entry_get_text(GTK_ENTRY(song_entry)));
+	gst_vorbis_tag_add (tag_list, GST_TAG_TITLE, gtk_entry_get_text(GTK_ENTRY(song_entry)));
+	gst_vorbis_tag_add (tag_list, GST_TAG_COPYRIGHT, gtk_entry_get_text(GTK_ENTRY(label_entry)));
+	gst_vorbis_tag_add (tag_list, GST_TAG_PUBLISHER, gtk_entry_get_text(GTK_ENTRY(label_entry)));
+	gst_vorbis_tag_add (tag_list, GST_TAG_DATE_TIME, datestamp);
+	gst_vorbis_tag_add (tag_list, GST_TAG_DATE_TIME, datestamp);
+	gst_stream_set_tags (GST_STREAM (recorder), tag_list);
 	main_loops = g_main_loop_new(NULL, TRUE);
 	g_main_loop_run(main_loops);
-
 	gst_element_set_state(recorder, GST_STATE_NULL);
 	g_main_loop_unref(main_loops);
 	gst_object_unref(GST_OBJECT(recorder));
@@ -124,6 +157,11 @@ static void gb_assistant_close(GtkAssistant * assistant, gpointer data)
 			gtk_entry_get_text(GTK_ENTRY(song_entry)),  "_[",
 			g_date_time_format_iso8601 (datestamp), "]",
 			".gingerblue", NULL);
+	g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
+			gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
+			gtk_entry_get_text(GTK_ENTRY(song_entry)),  "_[",
+			g_date_time_format_iso8601 (datestamp), "]",
+			".ogg", NULL);
 	fp = fopen(filename, "w");
 	fprintf(fp, "<?xml version='1.0' encoding='UTF-8'?>\n");
 	fprintf(fp, "<gingerblue version='%s'>\n", VERSION);
@@ -141,6 +179,8 @@ static void gb_assistant_close(GtkAssistant * assistant, gpointer data)
 		gtk_entry_get_text(GTK_ENTRY(computer_entry)));
 	fprintf(fp, "  <filename>%s</filename>\n",
 		gtk_entry_get_text(GTK_ENTRY(recording_entry)));
+	fprintf(fp, "  <album>%s</album>\n",
+		gtk_entry_get_text(GTK_ENTRY(album_entry)));
 	fprintf(fp, "  <studio>%s</studio>\n",
 		gtk_entry_get_text(GTK_ENTRY(studio_entry)));
 	fprintf(fp, "</gingerblue>\n");
@@ -153,7 +193,7 @@ static void gb_assistant_apply(GtkAssistant * assistant, gpointer data)
         GingerblueData *gingerblue_config;
         GtkWindow *gingerblue_window;
         /* gtk_init (&argc, &argv); */
-        gingerblue_config = main_config (gtk_entry_get_text(GTK_ENTRY(studio_entry)));
+        gingerblue_config = main_config (GTK_WIDGET(gingerblue_window), gtk_entry_get_text(GTK_ENTRY(studio_entry)));
         gingerblue_window = gingerblue_main_loop (gingerblue_config);
         gtk_widget_show_all (gingerblue_window);
         /* gst_init(&argc, &argc); */
@@ -172,7 +212,6 @@ int main(int argc, char **argv)
 	GDateTime *datestamp;
 	GingerblueData *data;
 	GingerblueChord *gingerblue_chord;
-	GstPlayer *player;
 	GstElement *src, *conv, *enc, *muxer, *sink, *pipeline;
 	GtkWidget *introduction;
 	GtkEntryBuffer *default_recording_title;
@@ -199,7 +238,8 @@ int main(int argc, char **argv)
 	GtkWidget *input_volume;
 	gdouble input_volume_value;
 	gint64 real_time;
-	PageInfo page[9] = {
+	gchar *album;
+	PageInfo page[11] = {
 		{NULL, -1, "Gingerblue Setup", GTK_ASSISTANT_PAGE_INTRO, TRUE},
 		{NULL, -1, "Musician", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Song", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
@@ -208,7 +248,9 @@ int main(int argc, char **argv)
 		{NULL, -1, "Label", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Computer", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Recording", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
-		{NULL, -1, "Studio", GTK_ASSISTANT_PAGE_CONFIRM, TRUE},
+		{NULL, -1, "Studio", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
+		{NULL, -1, "Album", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
+		{NULL, -1, "Broadcasting", GTK_ASSISTANT_PAGE_CONFIRM, TRUE},
 	};
 	datestamp = g_date_time_new_now_utc ();
 	gchar *filename = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
@@ -223,7 +265,7 @@ int main(int argc, char **argv)
 	gtk_window_set_title(GTK_WINDOW(introduction), "GNOME Gingerblue");
 	g_signal_connect(G_OBJECT(introduction), "destroy",
 			 G_CALLBACK(gtk_main_quit), NULL);
-	page[0].widget = gtk_label_new(_("Welcome to GNOME Gingerblue!\n\nClick Next to setup a music recording session!"));
+	page[0].widget = gtk_label_new(_("Welcome to GNOME Gingerblue!\n\nRecord respectfully around others.\n\nClick Next to setup a music recording session!\n\nClick Cancel to stop the music recording session.\n\nClick Cancel twice to exit GNOME Gingerblue."));
 	page[1].widget = gtk_box_new(FALSE, 5);
 	musician_label = gtk_label_new(_("Musician:"));
 	musician_entry = gtk_entry_new();
@@ -294,19 +336,58 @@ int main(int argc, char **argv)
 			   FALSE, FALSE, 5);
 	gtk_box_pack_start(GTK_BOX(page[7].widget), GTK_WIDGET(recording_entry),
 			   FALSE, FALSE, 5);
-	studio_label = gtk_button_new_with_label("Studio");
+	studio_label = gtk_button_new_with_label("Broadcasting");
 	studio_entry = gtk_entry_new();
-	if (g_strcmp0(studio_entry, NULL)!=0) gtk_entry_set_text(GTK_ENTRY(studio_entry), "studio.gingerblue.org"); else gtk_entry_set_text(GTK_ENTRY(studio_entry), gtk_entry_get_text(GTK_ENTRY(studio_entry)));
+	gtk_entry_set_text(GTK_ENTRY(studio_entry), g_strconcat("http://", gtk_entry_get_text(GTK_ENTRY(computer_entry)), "/", NULL));
 	g_signal_connect(G_OBJECT(studio_label), "clicked",
 			 G_CALLBACK(gb_assistant_apply),
 		         gtk_entry_get_text(GTK_ENTRY(studio_entry)));
+	g_signal_connect(G_OBJECT(studio_entry), "clicked",
+			 G_CALLBACK(gb_assistant_apply),
+		         gtk_entry_get_text(GTK_ENTRY(studio_entry)));
 	page[8].widget = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(page[8].widget), gtk_entry_get_text(GTK_ENTRY(studio_entry)));
 	gtk_box_pack_start(GTK_BOX(page[8].widget), GTK_WIDGET(studio_label),
 			   FALSE, FALSE, 5);
 	gtk_box_pack_start(GTK_BOX(page[8].widget), GTK_WIDGET(studio_entry),
 			   FALSE, FALSE, 5);
-	for (i = 0; i < 9; i++) {
+	album_label = gtk_label_new("Album");
+	album_entry = gtk_entry_new();
+	g_signal_connect(G_OBJECT(album_label), "clicked",
+			 G_CALLBACK(gb_assistant_apply),
+			 gtk_entry_get_text(GTK_ENTRY(album_entry)));
+	album = g_strconcat(gtk_entry_get_text(GTK_ENTRY(studio_entry)),
+			       gtk_entry_get_text(GTK_ENTRY(label_entry)),
+			       ".pls", NULL);
+	gtk_entry_set_text(GTK_ENTRY(album_entry), (gchar *)album);
+	page[9].widget = gtk_entry_new();
+	gtk_entry_set_text(GTK_ENTRY(page[9].widget), album);
+	g_signal_connect (GTK_BUTTON(album_entry), "clicked", G_CALLBACK(gb_assistant_apply), GTK_ENTRY(album_entry));
+	g_signal_connect (GTK_BOX(page[9].widget), "clicked", G_CALLBACK(gb_assistant_apply), GTK_ENTRY(album_entry));
+	g_signal_connect(G_OBJECT(album_label), "clicked",
+			 G_CALLBACK(gb_assistant_apply),
+			 album_entry);
+	gtk_box_pack_start(GTK_BOX(page[9].widget), GTK_WIDGET(album_label),
+			   FALSE, FALSE, 5);
+	gtk_box_pack_start(GTK_BOX(page[9].widget), GTK_WIDGET(album_entry),
+			   FALSE, FALSE, 5);
+	stream_label = gtk_button_new_with_label("Protocol");
+	stream_entry = gtk_entry_new();
+	gtk_entry_set_text(GTK_ENTRY(stream_entry), "Torrent");
+	g_signal_connect(G_OBJECT(stream_entry), "clicked",
+			 G_CALLBACK(gb_assistant_apply),
+		         gtk_entry_get_text(GTK_ENTRY(stream_entry)));
+	page[10].widget = gtk_label_new(_("Click to launch HTTP streaming server client"));
+	gtk_entry_set_text(GTK_ENTRY(page[10].widget), "Click Apply");
+	g_signal_connect (GTK_BUTTON(stream_entry), "clicked", G_CALLBACK(gb_assistant_apply), gtk_entry_get_text(GTK_ENTRY(studio_entry)));
+	g_signal_connect(G_OBJECT(stream_label), "clicked",
+			 G_CALLBACK(gb_assistant_apply),
+		         gtk_entry_get_text(GTK_ENTRY(stream_entry)));
+	gtk_box_pack_start(GTK_BOX(page[10].widget), GTK_WIDGET(stream_label),
+			   FALSE, FALSE, 5);
+	gtk_box_pack_start(GTK_BOX(page[10].widget), GTK_WIDGET(stream_entry),
+			   FALSE, FALSE, 5);
+	for (i = 0; i < 11; i++) {
 	        page[i].index = gtk_assistant_append_page(GTK_ASSISTANT(introduction),
 					      GTK_WIDGET(page[i].widget));
 		gtk_assistant_set_page_title(GTK_ASSISTANT(introduction),
@@ -429,7 +510,7 @@ int main(int argc, char **argv)
 			 G_CALLBACK(gtk_main_quit), NULL);
 
 	/* g_free (gingerblue_data); */
-	/* play_free (player); */
+
 	g_date_time_unref (datestamp);
 
 	gtk_main();
