@@ -3,7 +3,7 @@
    Copyright (C) 2018-2021 Aamot Software
    Author(s): Ole Aamot <ole@gnome.org>
    License: GNU GPL version 3
-   Version: 0.7.0 (2021-07-14)
+   Version: 1.1.0 (2021-07-27)
    Website: http://www.gingerblue.org/
  
  */
@@ -11,10 +11,16 @@
 #ifndef _GINGERBLUE_H_
 #define _GINGERBLUE_H_ 1
 
+#include <gtk/gtk.h>
+
+#define GINGERBLUE_STUDIO_PLAYER_TRUE 1
+#define GINGERBLUE_STUDIO_PLAYER_FALSE 0
+
 typedef struct _GingerblueData GingerblueData;
 
 struct _GingerblueData {
 	GtkWidget *knob;
+	gint player_status;
 	gchar *line;
 	gint jack;
 	gchar *label;
@@ -27,6 +33,7 @@ struct _GingerblueData {
 	GingerblueData *next;
 	GingerblueData *prev;
 	GtkWidget *window;
+	GMainLoop *player_loop;
 };
 
 void gb_window_break_record (GtkButton *record, GtkVolumeButton *volume);
